#
# spec file for package qqc2-desktop-style
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _tar_path 5.71
# Only needed for the package signature condition
%bcond_without lang
Name:           qqc2-desktop-style
Version:        5.71.0
Release:        lp152.2.3.1
Summary:        A Qt Quick Controls 2 Style for Desktop UIs
License:        GPL-2.0-or-later
Group:          Development/Libraries/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/frameworks/%{_tar_path}/qqc2-desktop-style-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/frameworks/%{_tar_path}/qqc2-desktop-style-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
# PATCH-FIX-UPSTREAM
Patch1:         0001-Don-t-use-parent-height-width-for-implicit-ToolSepar.patch
BuildRequires:  extra-cmake-modules >= 0.0.8
# For dir ownership
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
# Make sure the required libqt5-qtquickcontrols2 package is usable
# See https://bugs.kde.org/413829#c3
%requires_eq    libqt5-qtquickcontrols2
# plasma5-workspace sets up the env variables so that this theme
# is picked by default. It still works fine without it (no requires),
# but looks better with it. By itself plasma5-workspace does not use
# it (yet), so only install it with libqt5-qtquickcontrols2.
Supplements:    packageand(plasma5-workspace:libqt5-qtquickcontrols2)
# For KUA users
Provides:       plasma5-qqc2-style = %{version}
Obsoletes:      plasma5-qqc2-style < %{version}

%description
A Qt Quick Controls 2 style engine that uses the desktop style
to draw controls with QStyle.

%package devel
Summary:        Development Files for Qt Quick Controls 2 Desktop Style
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Requires:       extra-cmake-modules

%description devel
This file contains cmake files to be used by projects that depend on
qqc2-desktop-style.
Usually not needed as it is only a runtime dependency.

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%files
%license LICENSE*
%{_kf5_qmldir}/QtQuick/Controls.2/org.kde.desktop/
%dir %{_kf5_qmldir}/org/
%dir %{_kf5_qmldir}/org/kde/
%dir %{_kf5_plugindir}/kf5/kirigami/
%{_kf5_plugindir}/kf5/kirigami/org.kde.desktop.so
%{_kf5_qmldir}/org/kde/qqc2desktopstyle/

%files devel
%{_kf5_libdir}/cmake/KF5QQC2DesktopStyle/
# Legacy alias with typo...
%{_kf5_libdir}/cmake/KF5QQC2DeskopStyle/

%changelog
* Mon Nov 23 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix ToolSeparator sizing (boo#1179004, kde#425949):
  * 0001-Don-t-use-parent-height-width-for-implicit-ToolSepar.patch
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Add ToolSeparator styling
  * Remove "pressed" from CheckIndicator "on" state (kde#421695)
  * support the Header group
  * Implement smallFont in Kirigami plugin
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * Detect QQC2 version at build time with actual detection.
  * [ComboBox] Use transparent dimmer
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * QQC2-Desktop-Style: Convert license headers to SPDX expressions
  * [Dialog] Use `ShadowedRectangle`
  * Fix sizing of CheckBox and RadioButton (kde#418447)
  * Use `ShadowedRectangle`
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * ScrollView: Use scrollbar height as bottom padding, not width
- Drop 0001-ScrollView-Use-scrollbar-height-as-bottom-padding-no.patch
* Mon Feb 10 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch 0001-ScrollView-Use-scrollbar-height-as-bottom-padding-no.patch
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * Remove scrollbar related workarounds from list delegates
  * [TabBar] Remove frame
  * Add active, link, visited, negative, neutral and positive background colors
  * fix paddings
  * use hasTransientTouchInput
  * always round x and y
  * support mobile mode scrollbar
  * ScrollView: Do not overlay scrollbars over contents
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * [ToolTip] Round position
  * Update size hint when font changes
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * Fix typo in name of installed CMake Config: Deskop->Desktop
  * Make it compile against qt5.14 without deprecated method
  * [TabBar] Use window color instead of button color (kde#413311)
  * bind enabled properties to the view enabled
  * [ToolTip] Base timeout on text length
  * [ComboBox] Don't dim Popup
  * [ComboBox] Don't indicate focus when popup is open
  * [ComboBox] Follow focusPolicy
* Thu Nov  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Make sure the required libqt5-qtquickcontrols2 package is usable (kde#413829)
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Do not assign combobox currentIndex as it breaks binding.
  * docs: fix typo te -> the
  * Fix warning when we're not hovering a Control
  * Listen to the application style changing
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Fix several build system errors
  * Fix typo
  * take margins from qstyle
  * [QQC2 Desktop Style] Port away from deprecated methods in Qt 5.14
  * [Tab] Fix sizing (kde#409390)
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Prevent dragging QQC2 ComboBox contents outside menu
  * metainfo.yaml: set fancy name, auto-name from cmake project() is not nice
  * metainfo.yaml: remove bogus note about library to link to
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Fix broken guard that prevents styling sliders with negative values
  * Slow down the busy indicator's rotation speed
  * Fix "Type error" when creating a TextField with focus: true
  * [ComboBox] Set close policy to close on click outside instead of only outside parent (kde#408950)
  * [SpinBox] Set renderType (kde#409888)
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
- Drop patch to support Qt 5.9:
  * 0001-Fix-MobileTextActionsToolBar.qml-with-Qt-5.9.patch
- Drop patch for Leap 42.3 which is EOL:
  * fix-build-with-gcc48.patch
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Remove Qt 5.11 ifdef since we require that version now
  * MobileTextActionsToolBar: fix runtime warnings when controlRoot isn't set yet (kde#408719)
  * Show shortcut in menu item when specified (kde#405541)
  * Add MenuSeparator
  * Fix ToolButton remaining in a pressed state after press
  * [ToolButton] Pass custom icon size to StyleItem
  * honor visibility policy (kde#407014)
- Refreshed patches:
  * 0001-Fix-MobileTextActionsToolBar.qml-with-Qt-5.9.patch
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Remove DefaultListItemBackground and MenuItem animation
  * [QQC2 Slider Style] Fix wrong handle positioning when initial value is 1 (kde#405471)
  * guard minimum and maximum for sliders
  * ScrollBar: Make it work as a horizontal scroll bar as well (kde#390351)
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * Avoid nesting Controls in TextField (kde#406851)
  * make the mobile text toolbar appear only on press
  * [TabBar] Update height when TabButtons are added dynamically
  * refer to the proper id
  * use the new Kirigami.WheelHandler
  * Support custom icon size for ToolButton
  * It compile fine without foreach
  Refreshed patches:
  * 0001-Fix-MobileTextActionsToolBar.qml-with-Qt-5.9.patch
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * the plasma desktop style supports icon coloring
  * [SpinBox] Improve mouse wheel behavior
  * add a bit of padding in ToolBars
  * fix RoundButton icons
  * scrollbar based padding on all delegates
  * look for a scrollview to take its scrollbar for margins
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Use PointingHand when hovering links in Label
  * Respect the display property of buttons
  * clicking on empty areas behaves like pgup/pgdown (kde#402578)
  * Support icon on ComboBox
  * support text positioning api
  * Support icons from local files in buttons
  * Use the correct cursor when hovering over the editable part of a spinbox
* Fri Feb 15 2019 alarrosa@suse.com
- Add 0001-Fix-MobileTextActionsToolBar.qml-with-Qt-5.9.patch (by Fabian Vogt)
  to fix an issue with Qt 5.9
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Fix combobox initial sizing (kde#403736)
  * Set combobox popups to be modal (kde#403403)
  * Tab bar test
  * partly revert 4f00b0cabc1230fdf
  * Word-wrap long tooltips (kde#396385)
  * ComboBox: fix default delegate
  * Fake mousehover whilst combobox is open
  * Set CombooBox QStyleOptionState == On rather than Sunken to match qwidgets
  * Fix ComboBox
  * Always draw the tooltip on top of everything else
  * Support a tooltip on a MouseArea
  * Minor: Use {} for initializing flags
  * Minor: Use nullptr
  * do not force text display for ToolButton
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Fix warning
  * Fix menu item width when the delegate is overriden (kde#401792)
  * Fix warnings
  * Rotate busy indicator clockwise
  * same behavior as Kirigami ScrollablePage
  * force checkboxes/radios to be square
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * consistent sizing of item compared to QWidgets
  * emit activated
  * same behavior as qwidgets comboboxes
  * fix Menu sizing
  * default values for ToolTip
  * proper line widths
  * make sure flickables are pixelAligned
  * Fix compilation
  * Support for QGuiApplication-based apps (kde#396287)
  * touchscreen text controls
  * Size according to specified icon width and height
  * Honor flat property of buttons
  * Remove qt include prefix
  * Fix issue where there's only one element on the menu
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * No code changes since 5.51.0
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * small default padding when there is a background
  * Make it compile with "KDEFrameworkCompilerSettings"
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * None
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Improve sizing of menus (kde#396841)
  * Remove double comparison
  * Port away from string-based connects
  * check for valid icon
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * no pixel values in checkindicator
  * own sizehit for sliders
  * use RadioIndicator for everybody
  * Don't overflow around popups
  * on Qt<5.11 the control palette is completely ignored
  * import kirigami 2.4
  * anchor button background
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Use pallet property only when using qtquickcontrols 2.4
  * work with Qt<5.10
  * add missing import
  * fix height of tabbar
  * Use Control.palette
  * --warnings
  * [RadioButton] Rename "control" to "controlRoot"
  * Don't set explicit spacing on RadioButton/CheckBox
  * [FocusRect] Use manual placement instead of anchors
  * import focusrect
  * import FocusRect
  * It turns out the flickable in a scrollview is the contentItem
  * Use override
  * Show focus rect when CheckBox or RadioButton are focused
  * hacky fix to scrollview detection
  * don't reparent the flickable to the mousearea
  * Add test file for ScrollView { TextArea {} }
  * [TabBar] Switch tabs with mouse wheel
  * Fix warning
  * Control must not have children (kde#394134)
  * constrain scroll (kde#393992)
- Dropped patches, now upstream:
  * control-must-not-have-children.patch
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * export layout paddings from qstyle, start from Control
  * [ComboBox] Fix mouse wheel handling
  * make the mousearea not interfere with controls
  * fix acceptableInput
  * remove useless debug
  * Fix warning
- Add upstream patch to fix control panel layouts (kde#394134):
  * control-must-not-have-children.patch
* Mon Apr 16 2018 wbauer@tmo.at
- Add fix-build-with-gcc48.patch to make it compile with gcc 4.8 on
  Leap 42.3
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * fix rendering when disabled
  * better layout
  * experimental support for auto mnemonics
  * We depend against 5.8.0
  * Make sure we are taking into account hte size of the element when styling
  * Fix font rendering for non-HiDPI and integer scale factors (kde#391780)
  * e our way to handle shortcuts
  * fix icons colors with colorsets
  * fix icon colors for toolbuttons
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Fix syntax error in previous commit, detected by launching ruqola
  * Show a radiobutton when we are showing an exclusive control
  * fix some Qt 5.9 bugs
  * implement MenuBarItem
  * fix logic
  * implement DelayButton
  * New component: round button
  * take into account toolbar position
  * support colors for icons in buttons
  * support --reverse
  * icons in Menu fully functional
  * consistent shadows with the new breeze style
  * ame behavior as qwidget menus
  * make icons actually work
  * Some QStyles seem to not return sensible pixelmetrics here
  * first rough icons support
  * don't wrap around with mouse wheel
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * use the inactive or disabled color group when needed
  * Apply some C++11 niceties, styling consistency
  * Add BusyIndicator to the styled controls list
  * remove flicker when hovering scrollbar
  * Cache KColorScheme instances
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * simplify and don't try to block mouse events
  * if no wheel.pixelDelta, use global wheel scroll lines
  * desktop tabbars have different widths for each tab
  * ensure a non 0 size hint
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * determine QQC2 version at build time (kde#386289)
  * by default, keep the background invisible
  * add a background in ScrollView
* Tue Nov 14 2017 wbauer@tmo.at
- Fix QtQuickControls2 BuildRequires, it needs the devel package to
  build
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Improve compilation as a static plugin.
  * make the radiobutton a radiobutton
  * use qstyle to paint the Dial
  * use a ColumnLayout for menus
  * fix Dialog
  * remove invalid group property
  * Add .arcconfig
  * Fix formatting of the md file so it matches the other modules
  * behavior of combobox closer to qqc1
  * workaround for QQuickWidgets
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Too many to list here
* Sat Aug 19 2017 fabian@ritter-vogt.de
- Initial packaging
